# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2021 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT
from .checkers import check_error_log, check_site_status_code
from .errors import WebsiteCheckError, RollbackException


def post_site_check(domain: str, wp_path: str, abs_wp_path: str):
    """
    Verifies that domain is still working
    after caching tool installation.

    Performs checks and gathers
    results in RollbackException if needed.

    :param domain:
        domain in format "domain.or.subdomain.zone"
    :param wp_path:
        relative path to wordpress installation against docroot
    :param abs_wp_path:
        absolute path to wordpress installation (same as docroot)
    :raises:
        RollbackException in case if installation must be reverted
    """

    rollback_reasons = []

    try:
        with check_error_log(abs_wp_path):
            try:
                check_site_status_code(domain, wp_path)
            except WebsiteCheckError as e:
                rollback_reasons.append(e)
    except WebsiteCheckError as e:
        rollback_reasons.append(e)

    if rollback_reasons:
        raise RollbackException(*rollback_reasons)
