#!/opt/alt/python37/bin/python3 -bb
# -*- coding: utf-8 -*-

# redis_reloader.py Utility to reload redis for user. Should be run only under root
#
# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2020 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT


# pylint: disable=no-absolute-import

import sys
import json
import traceback

from clwpos.utils import error_and_exit, is_run_under_user
from clwpos.object_cache.reloader_redis_lib import reload_redis_for_user

if __name__ == "__main__":
    if is_run_under_user():
        error_and_exit(True, {'result': 'Redis runner should be run only under root'})
    try:
        user_name = sys.argv[1]
        s_old_redis_pid = sys.argv[2]
    except IndexError:
        error_and_exit(True, {'result': 'Redis runner error: username or old redis PID not passed'})
    try:
        old_redis_pid = int(s_old_redis_pid)
    except (TypeError, ValueError):
        # s_old_redis_pid == 'None', no old redis process
        old_redis_pid = -1
    try:
        result_dict = reload_redis_for_user(user_name, old_redis_pid)
        print(json.dumps(result_dict))
    except Exception:
        print(json.dumps({'result': 'Unexpected redis runner error: %(message)s', 'message': traceback.format_exc()}))
